'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.oneOf = exports.isNotEqual = exports.isEqual = exports.isEmail = exports.isAlphanumeric = exports.minAge = exports.maxAge = exports.validDate = exports.minLength = exports.maxLength = exports.required = exports.normalizeUsername = exports.normalizeDate = undefined;

var _normalizers = require('./normalizers');

Object.defineProperty(exports, 'normalizeDate', {
  enumerable: true,
  get: function get() {
    return _normalizers.normalizeDate;
  }
});
Object.defineProperty(exports, 'normalizeUsername', {
  enumerable: true,
  get: function get() {
    return _normalizers.normalizeUsername;
  }
});

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _isemail = require('@anchorchat/isemail');

var _isemail2 = _interopRequireDefault(_isemail);

var _getAge = require('./get-age');

var _getAge2 = _interopRequireDefault(_getAge);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var required = exports.required = function required(value) {
  var error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  return value ? undefined : error;
};

var maxLength = exports.maxLength = function maxLength(max) {
  return function (value) {
    var error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    return value && value.length > max ? error : undefined;
  };
};

var minLength = exports.minLength = function minLength(min) {
  return function (value) {
    var error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    return value && value.length < min ? error : undefined;
  };
};

var validDate = exports.validDate = function validDate(format) {
  return function (value) {
    var error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    return !format || !(0, _moment2.default)(value, format, true).isValid() ? error : undefined;
  };
};

var maxAge = exports.maxAge = function maxAge(max, format) {
  return function (value) {
    var error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    return (0, _getAge2.default)(value, format) > max ? error : undefined;
  };
};

var minAge = exports.minAge = function minAge(min, format) {
  return function (value) {
    var error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    return (0, _getAge2.default)(value, format) < min ? error : undefined;
  };
};

var isAlphanumeric = exports.isAlphanumeric = function isAlphanumeric(value) {
  var error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  return value && /[^a-zA-Z0-9]/.test(value) ? error : undefined;
};

var isEmail = exports.isEmail = function isEmail(value) {
  var error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  return !_isemail2.default.validate(value) ? error : undefined;
};

var isEqual = exports.isEqual = function isEqual(value, comparison) {
  var error = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  return value && comparison && value !== comparison ? error : undefined;
};

var isNotEqual = exports.isNotEqual = function isNotEqual(value, comparison) {
  var error = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  return value && comparison && value === comparison ? error : undefined;
};

var oneOf = exports.oneOf = function oneOf(fn1, fn2) {
  var error = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  return fn1 && fn2 ? error : undefined;
};